/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.util;

public final class AnyCharMatcher
{
  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private char[] charset;
  private int[] locs;

  /*--------------------------------------------------------------------------------
   * Constructors
   *--------------------------------------------------------------------------------
   */

  public AnyCharMatcher(char[] charset)
  {
    this.charset = charset;
    this.locs = new int[charset.length];

  } // end constructor

  public AnyCharMatcher(String charset)
  {
    this.charset = charset.toCharArray();
    this.locs = new int[charset.length()];

  } // end constructor

  /*--------------------------------------------------------------------------------
   * External operations
   *--------------------------------------------------------------------------------
   */

  public final int get(String str)
  {
    int numindexes = 0;
    int i;
    for (i=0; i<charset.length; i++)
    { // locate the index of the first HTML character
      int tmp = str.indexOf(charset[i]);
      if (tmp>=0)
	locs[numindexes++] = tmp;

    } // end for

    if (numindexes==0)
      return -1;  // no characters found
    else if (numindexes==1)
      return locs[0];  // only one found

    int rc = locs[0];
    for (i=1; i<numindexes; i++)
    { // this loop determines the lowest possible return value
      if (rc==0)
	return 0;  // can't get any lower!
      if (locs[i]<rc)
	rc = locs[i];  // this is now the lowest

    } // end for

    return rc;

  } // end get

} // end class AnyCharMatcher

