/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.util;

import java.io.*;

/* Some concepts in here borrowed from Apache Jakarta Avalon Excalibur 4.0 */

public class IOUtil
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  public static int DEFAULT_BUFSIZE = 4096;

  /*--------------------------------------------------------------------------------
   * External static operations
   *--------------------------------------------------------------------------------
   */

  public static void shutdown(InputStream stm)
  {
    try
    { // close the stream
      stm.close();

    } // end try
    catch (IOException e)
    { // throw away the exception
    } // end catch

  } // end shutdown

  public static void shutdown(OutputStream stm)
  {
    try
    { // close the stream
      stm.close();

    } // end try
    catch (IOException e)
    { // throw away the exception
    } // end catch

  } // end shutdown

  public static void shutdown(Reader rdr)
  {
    try
    { // close the stream
      rdr.close();

    } // end try
    catch (IOException e)
    { // throw away the exception
    } // end catch

  } // end shutdown

  public static void shutdown(Writer wr)
  {
    try
    { // close the stream
      wr.close();

    } // end try
    catch (IOException e)
    { // throw away the exception
    } // end catch

  } // end shutdown

  public static void copy(InputStream input, OutputStream output, int bufsize) throws IOException
  {
    byte[] buffer = new byte[bufsize];
    int rd = input.read(buffer);
    while (rd>=0)
    { // simple read-write loop to shove data out the door
      if (rd>0)
	output.write(buffer,0,rd);
      rd = input.read(buffer);

    } // end while

  } // end copy

  public static void copy(InputStream input, OutputStream output) throws IOException
  {
    copy(input,output,DEFAULT_BUFSIZE);

  } // end copy

  public static void copy(Reader input, Writer output, int bufsize) throws IOException
  {
    char[] buffer = new char[bufsize];
    int rd = input.read(buffer);
    while (rd>=0)
    { // simple read-write loop to shove data out the door
      if (rd>0)
	output.write(buffer,0,rd);
      rd = input.read(buffer);

    } // end while

  } // end copy

  public static void copy(Reader input, Writer output) throws IOException
  {
    copy(input,output,DEFAULT_BUFSIZE);

  } // end copy

  public static StringBuffer load(Reader input, int bufsize) throws IOException
  {
    StringWriter wr = new StringWriter();
    try
    { // copy from reader to StringWriter
      copy(input,wr,bufsize);
      return wr.getBuffer();

    } // end try
    finally
    { // make sure and close the StringWriter before we go
      shutdown(wr);

    } // end finally

  } // end load

  public static StringBuffer load(Reader input) throws IOException
  {
    return load(input,DEFAULT_BUFSIZE);

  } // end load

  public static StringBuffer load(File file, int bufsize) throws IOException
  {
    FileReader rdr = new FileReader(file);
    try
    { // load from the string reader
      return load(rdr,bufsize);

    } // end try
    finally
    { // make sure and close the reader before we go
      shutdown(rdr);

    } // end finally

  } // end load

  public static StringBuffer load(File file) throws IOException
  {
    return load(file,DEFAULT_BUFSIZE);

  } // end load

} // end class IOUtil
